@@ -1,5 +1,9 @@
 """
+a small tool to assign students(workers) to projects(jobs)
+based on their rank of preference(cost) to each of the projects(jobs)
 
+Two functions, *assign_project()* and *generate_sample()*, realize
+the facility.
 """
 
 from munkres import Munkres
@@ -9,22 +13,19 @@ from datetime import datetime
 import random
 
 
-def assign_project(csv_name, **kwargs):
-    """
+def assign_project(csv_name, capacity, **kwargs):
+    """This function is for assigning.
 
-    :param csv_name:
-    :param kwargs:
-    :return:
+    :param csv_name: The name of the input csv file.
+    :param capacity: the number of students that a project can take at most.
+    :param kwargs: **argument. Can take "output", "time" and "deviation" 3 fields. Please see README file for details
+    :return: None
     """
 
     start_time = datetime.now()
-    matrix = __convert_csv(csv_name)
+    matrix = __convert_csv(csv_name, capacity)
     student_num = len(matrix)
-    project_num = len(matrix[0]) // 5
-
-    if "check" in kwargs and kwargs["check"]:
-        wb = openpyxl.load_workbook("../tests/data.xlsx")
-        sheet = wb["Sheet1"]
+    project_num = len(matrix[0]) // capacity
 
     if "output" in kwargs and kwargs["output"] == "file":
         result = openpyxl.Workbook()
@@ -58,10 +59,6 @@ def assign_project(csv_name, **kwargs):
             result_sheet_p.cell(column % project_num + 2,
                                 project_assigned_people[column % project_num] + 1).value = row + 1
 
-        if "check" in kwargs and kwargs["check"]:
-            cell = sheet.cell(row + 1, column % project_num + 1)
-            assert value == cell.value
-
         assigned_choices.append(value)
 
     if "deviation" not in kwargs or kwargs["deviation"]:
@@ -79,7 +76,7 @@ def assign_project(csv_name, **kwargs):
         result.save("result.xlsx")
 
 
-def __convert_csv(csv_name):
+def __convert_csv(csv_name, capacity):
     with open(csv_name, encoding='UTF-8-sig') as source:
         reader = csv.reader(source)
         matrix = []
@@ -90,7 +87,7 @@ def __convert_csv(csv_name):
                     line.append(20)
                 else:
                     line.append(int(number))
-            line *= 5
+            line *= capacity
             matrix.append(line)
     return matrix
 
@@ -111,10 +108,10 @@ def __calculate_s(int_list):
 def generate_sample(csv_name, student_num, project_num):
     """
 
-    :param csv_name:
+    :param csv_name: The name of the output csv file.
     :param student_num:
     :param project_num:
-    :return:
+    :return: None
     """
     with open(csv_name, "w") as target:
         writer = csv.writer(target)
